%define srcname nmstate
%define libname libnmstate

Name:           nmstate
Version:        2.1.2
Release:        2%{?dist}
Summary:        Declarative network manager API
License:        LGPLv2+
URL:            https://github.com/%{srcname}/%{srcname}
Source0:        %{url}/releases/download/v%{version}/%{srcname}-%{version}.tar.gz
Source1:        %{url}/releases/download/v%{version}/%{srcname}-%{version}.tar.gz.asc
Source2:        https://nmstate.io/nmstate.gpg
Patch1:         use_uuid_1_1.patch
BuildRequires:  patchelf
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  gnupg2
BuildRequires:  systemd-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  rust-packaging
BuildRequires:  (crate(serde/default) >= 1.0 with crate(serde/default) < 2.0)
BuildRequires:  (crate(serde/derive) >= 1.0 with crate(serde/derive) < 2.0)
BuildRequires:  (crate(serde_json/default) >= 1.0 with crate(serde_json/default) < 2.0)
BuildRequires:  (crate(serde_yaml/default) >= 0.8 with crate(serde_yaml/default) < 0.9)
BuildRequires:  (crate(uuid/v4) >= 1.1 with crate(uuid/v4) < 2.0)
BuildRequires:  (crate(uuid/v5) >= 1.1 with crate(uuid/v5) < 2.0)
BuildRequires:  (crate(zbus/default) >= 1.9 with crate(zbus/default) < 2.0)
BuildRequires:  (crate(zvariant/default) >= 2.10 with crate(zvariant/default) < 3.0)
BuildRequires:  (crate(log/default) >= 0.4 with crate(log/default) < 0.5)
BuildRequires:  (crate(libc/default) >= 0.2 with crate(libc/default) < 0.3)
BuildRequires:  (crate(clap/default) >= 3.1 with crate(clap/default) < 4.0)
BuildRequires:  (crate(clap/cargo) >= 3.1 with crate(clap/cargo) < 4.0)
BuildRequires:  (crate(ctrlc/default) >= 3.2 with crate(ctrlc/default) < 4.0)
BuildRequires:  (crate(env_logger/default) >= 0.9 with crate(env_logger/default) < 1.0)
BuildRequires:  (crate(nispor/default) >= 1.2.7 with crate(nispor/default) < 2.0)

%description
Nmstate is a library with an accompanying command line tool that manages host
networking settings in a declarative manner and aimed to satisfy enterprise
needs to manage host networking through a northbound declarative API and multi
provider support on the southbound.


%package libs
Summary:        C binding of nmstate
# Use Recommends for NetworkManager because only access to NM DBus is required,
# but NM could be running on a different host
Recommends:     NetworkManager
# Avoid automatically generated profiles
Recommends:     NetworkManager-config-server
License:        ASL 2.0

%description libs
C binding of nmstate.

%package devel
Summary:        Development files for nmstate
Group:          Development/Libraries
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}
License:        ASL 2.0

%description devel
Development files of nmstate C binding.

%package static
Summary:        Static development files for nmstate
Group:          Development/Libraries
Requires:       %{name}-devel%{?_isa} = %{version}-%{release}

%description static
Static C library bindings for nmstate.

%package -n python3-%{libname}
Summary:        nmstate Python 3 API library
# Use Recommends for NetworkManager because only access to NM DBus is required,
# but NM could be running on a different host
Recommends:     NetworkManager
# Avoid automatically generated profiles
Recommends:     NetworkManager-config-server
Recommends:     (nmstate-plugin-ovsdb if openvswitch)
# Use Suggests for NetworkManager-ovs and NetworkManager-team since it is only
# required for OVS and team support
Suggests:       NetworkManager-ovs
Suggests:       NetworkManager-team
Provides:       nmstate-plugin-ovsdb = %{version}-%{release}
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}
Obsoletes:      nmstate-plugin-ovsdb < 2.0-1

%description -n python3-%{libname}
This package contains the Python 3 library for Nmstate.

%package -n rust-%{name}-devel
Summary:        Rust crate of nmstate
BuildArch:      noarch

%description -n rust-%{name}-devel
This package contains library source intended for building other packages
which use "%{name}" crate.

%package -n rust-%{name}+default-devel
Summary:        Rust crate of nmstate with default feature
BuildArch:      noarch

%description -n rust-%{name}+default-devel
This package contains library source intended for building other packages
which use "%{name}" crate with default feature.

%prep
gpg2 --import --import-options import-export,import-minimal \
    %{SOURCE2} > ./gpgkey-mantainers.gpg
gpgv2 --keyring ./gpgkey-mantainers.gpg %{SOURCE1} %{SOURCE0}
%autosetup -p1

pushd rust
rm .cargo/config.toml
%cargo_prep
popd

%build
pushd rust
%cargo_build
popd

pushd rust/src/python
%py3_build
popd

%install
env SKIP_PYTHON_INSTALL=1 \
    PREFIX=%{_prefix} \
    LIBDIR=%{_libdir} \
    SYSCONFDIR=%{_sysconfdir} \
    %make_install
patchelf --set-soname libnmstate.so.2 \
    %{buildroot}/%{_libdir}/libnmstate.so.%{version}

pushd rust/src/python
%py3_install
popd

pushd rust/src/lib
%cargo_install
popd

%files
%doc README.md
%doc examples/
%{_mandir}/man8/nmstatectl.8*
%{_mandir}/man8/nmstate-autoconf.8*
%{_mandir}/man8/nmstate.service.8*
%{_bindir}/nmstatectl
%{_bindir}/nmstate-autoconf
%{_unitdir}/nmstate.service
%dir %{_sysconfdir}/%{name}
%{_sysconfdir}/%{name}/README

%files libs
%{_libdir}/libnmstate.so.*

%files devel
%{_libdir}/libnmstate.so
%{_includedir}/nmstate.h
%{_libdir}/pkgconfig/nmstate.pc

%files -n python3-%{libname}
%license LICENSE
%{python3_sitelib}/%{libname}
%{python3_sitelib}/%{srcname}-*.egg-info/

%files -n rust-%{name}-devel
%license LICENSE
%{cargo_registry}/%{name}-%{version}/

%files -n rust-%{name}+default-devel
%ghost %{cargo_registry}/%{name}-%{version}/Cargo.toml

%files static
%{_libdir}/libnmstate.a

%changelog
* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> 2.1.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jul 11 2022 Gris Ge <fge@redhat.com> 2.1.2-1
- Upgrade to nmstate 2.1.2

* Wed Jun 29 2022 Gris Ge <fge@redhat.com> 2.1.0-8
- WIP

* Tue Jun 14 2022 Python Maint <python-maint@redhat.com> 2.1.0-7
- Rebuilt for Python 3.11

* Fri Apr 22 2022 Gris Ge <fge@redhat.com> 2.1.0-6
- Upgrade to 2.1.0 release

* Tue Apr 19 2022 Gris Ge <fge@redhat.com> 2.1.0-5
- Add license for -libs and -devel

* Tue Apr 19 2022 Gris Ge <fge@redhat.com> 2.1.0-4
- The rust CLI does not require libs

* Tue Apr 19 2022 Gris Ge <fge@redhat.com> 2.1.0-3
- Upgrade to 2.1.0.alpha2

* Wed Apr 13 2022 Gris Ge <fge@redhat.com> 2.1.0-2
- Change the python binding to noarch

* Wed Apr 13 2022 Gris Ge <fge@redhat.com> 2.1.0-1
- Upgrade to 2.1.0.alpha1

* Tue Feb 15 2022 Fernando Fernandez Mancera <ffmancera@riseup.net> 2.0.0-1
- Upgrade to 2.0.0

* Tue Feb 01 2022 Fernando Fernandez Mancera <ffmancera@riseup.net> 1.2.0-1
- Upgrade to 1.2.0

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> 1.1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Tue Jul 27 2021 Gris Ge <cnfourt@gmail.com> 1.1.0-2
- Add varlink service back.

* Tue Jul 27 2021 Gris Ge <cnfourt@gmail.com> 1.1.0-1
- Upgrade to 1.1.0

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> 1.0.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> 1.0.3-3
- Rebuilt for Python 3.10

* Mon Apr 19 2021 Fernando Fernandez Mancera <ffmancera@riseup.net> 1.0.3-2
- Fix installation nmstate-varlink.service

* Thu Apr 15 2021 Fernando Fernandez Mancera <ffmancera@riseup.net> 1.0.3-1
- Upgrade to 1.0.3

* Sun Feb 21 2021 Fernando Fernandez Mancera <ffmancera@riseup.net> 1.0.2-1
- Upgrade to 1.0.2

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> 1.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Mon Jan 18 2021 Fernando Fernandez Mancera <ffmancera@riseup.net> 1.0.1-1
- Upgrade to 1.0.1

* Tue Dec 08 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 1.0.0-1
- Upgrade to 1.0.0

* Thu Oct 22 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.4.1-1
- Upgrade to 0.4.1

* Mon Oct 12 2020 Gris Ge <cnfourt@gmail.com> 0.4.0-2
- Fix the ELN build by put ovs stuff as soft requirement.

* Sun Sep 20 2020 Gris Ge <cnfourt@gmail.com> 0.4.0-1
- Upgrade to 0.4.0

* Mon Aug 31 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.3.5-1
- Update to 0.3.5

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> 0.3.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sat Jul 25 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.3.4-1
- Update to 0.3.4

* Thu Jul 02 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.3.3-1
- Update to 0.3.3

* Mon Jun 15 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.3.2-1
- Update to 0.3.2

* Tue Jun 09 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.3.1-1
- Update to 0.3.1

* Tue May 26 2020 Miro Hrončok <miro@hroncok.cz> 0.3.0-5
- Rebuilt for Python 3.9

* Fri May 08 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.3.0-4
- Fix missing source

* Fri May 08 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.3.0-3
- Fix signature verification

* Fri May 08 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.3.0-2
- Update signature verification

* Fri May 08 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.3.0-1
- Update to 0.3.0

* Tue Apr 21 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.2.10-1
- Update to 0.2.10

* Thu Mar 26 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.2.9-1
- Update to 0.2.9

* Fri Mar 13 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.2.8-1
- Update to 0.2.8

* Wed Mar 04 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.2.7-1
- Update to 0.2.7

* Mon Feb 24 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.2.6-1
- Update to 0.2.6

* Wed Feb 19 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.2.5-1
- Update to 0.2.5

* Wed Feb 12 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.2.4-1
- Update to 0.2.4

* Wed Feb 05 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.2.3-1
- Update to 0.2.3

* Tue Feb 04 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.2.2-1
- Update to 0.2.2

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> 0.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Jan 13 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.2.1-2
- Fix changelog

* Mon Jan 13 2020 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.2.1-1
- Update to 0.2.1

* Mon Dec 09 2019 Till Maas <opensource@till.name> 0.2.0-3
- Use ascii-armored keyring

* Tue Dec 03 2019 Fernando Fernandez Mancera <ffmancera@riseup.net> 0.2.0-2
- Fix changelog

* Tue Dec 03 2019 Fernando Fernandez Mancera <ferferna@redhat.com> 0.2.0-1
- Update to 0.2.0

* Mon Dec 02 2019 Till Maas <opensource@till.name> 0.1.1-1
- Update to 0.1.1 and sync spec file

* Thu Oct 03 2019 Miro Hrončok <miro@hroncok.cz> 0.0.8-3
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Mon Aug 19 2019 Miro Hrončok <miro@hroncok.cz> 0.0.8-2
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Gris Ge <fge@redhat.com> 0.0.8-1
- Upgrade to 0.0.8.

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> 0.0.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Jun 14 2019 Gris Ge <fge@redhat.com> 0.0.7-2
- Workaround broken dbus-python packaging:
  https://bugzilla.redhat.com/show_bug.cgi?id=1654774

* Fri Jun 14 2019 Gris Ge <fge@redhat.com> 0.0.7-1
- Upgrade to 0.0.7

* Sun May 05 2019 Gris Ge <fge@redhat.com> 0.0.6-1
- Upgrade to 0.0.6

* Fri Apr 12 2019 Gris Ge <fge@redhat.com> 0.0.5-3
- Add missing runtime requirement: python3-dbus

* Tue Mar 12 2019 Gris Ge <fge@redhat.com> 0.0.5-1
- Upgrade to 0.0.5

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> 0.0.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Tue Jan 29 2019 Till Maas <opensource@till.name> 0.0.4-2
- Sync with upstream spec

* Thu Jan 24 2019 Gris Ge <fge@redhat.com> 0.0.4-1
- Upgrade to 0.0.4.

* Mon Jan 21 2019 Gris Ge <fge@redhat.com> 0.0.3-3
- Add missing runtime dependency for nmstatectl.

* Wed Jan 02 2019 Gris Ge <fge@redhat.com> 0.0.3-2
- Add source file PGP verification.

* Thu Dec 20 2018 Gris Ge <fge@redhat.com> 0.0.3-1
- Upgrade to 0.0.3.

* Wed Dec 19 2018 Gris Ge <fge@redhat.com> 0.0.2-1
- Initial import (RHBZ#1654666)
